#ifndef EDITOR_H
#define EDITOR_H

#include <QMainWindow>
#include <QFile>
#include <QDebug>
#include <QFileDialog>
#include <QMessageBox>
#include <QTextEdit>
#include <QVector>
#include <QCloseEvent>
#include <QStringListModel>
#include <QFileSystemModel>
#include <QPrinter>
#include <QTextDocument>
#include <QTableWidget>
#include "ui_editor.h"

class Editor : public QMainWindow, private Ui::Editor
{
    Q_OBJECT
public:
    explicit Editor(QWidget *parent = 0);
    void closeEvent(QCloseEvent* event);

    struct Tab
    {
        QTextEdit* m_textEdit;
        QFile* m_file;
        bool m_saved = true;
    };

private:

    QVector<Tab> m_tabs;

    QFileSystemModel *m_fileModel;
    QStringListModel *m_listModel;
    QStringList *m_list;

    void toggleActions(bool flag);

public slots:
    void slotOpen();
    void slotNew();
    void slotSave();
    void slotSaveAs();
    void slotSaveAll();
    void slotClose();
    void slotCloseAll();
    void slotQuit();
    void slotCut();
    void slotCopy();
    void slotPase();
    void slotDelete();
    void slotSelectAll();
    void slotViewer(bool toggle);
    void slotExplorer(bool toggle);
    void slotAbout();
    void slotChanged();
    void slotCloseTab(int index);
    void slotExplorerOpen(QModelIndex index);
    void slotSelectTab(QModelIndex index);
};

#endif // EDITOR_H
